@@ -14,7 +14,7 @@
 #   limitations under the License.
 
 __author__ = 'Michael Gruber'
-__version__ = '0.0.9'
+__version__ = '0.0.10'
 
 
 from mock import patch
@@ -183,10 +183,6 @@ class FluentWhen(FluentTargeting):
         FluentTargeting.__init__(self, target)
 
     def __getattr__(self, name):
-        if not hasattr(self._target, name):
-            raise FluentMockException(MESSAGE_INVALID_ATTRIBUTE.format(target_name=self._target_name,
-                                                                       attribute_name=name))
-
         original = getattr(self._target, name)
         stub_entry = FluentStubEntry(self._target, name, original)
         _stubs.append(stub_entry)
